#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_BITWISE_CAST_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_BITWISE_CAST_HPP_INCLUDED

#include <boost/simd/memory/include/functions/bitwise_cast.hpp>

#endif
